@@ -90,13 +90,14 @@ def create_sorted_many_to_many_intermediate_model(field, klass):
         if django.VERSION < (1, 6):
             return model._default_manager.count()
         else:
-            from django.db.utils import OperationalError
+            from django.db.utils import ProgrammingError, OperationalError
             try:
                 # We need to catch if the model is not yet migrated in the
                 # database. The default function is still called in this case while
                 # running the migration. So we mock the return value of 0.
-                return model._default_manager.count()
-            except OperationalError:
+                with transaction.atomic():
+                    return model._default_manager.count()
+            except (ProgrammingError, OperationalError):
                 return 0
 
     default_sort_value = curry(default_sort_value, name)
